import Button from 'react-bootstrap/Button';
import Modal from 'react-bootstrap/Modal';
import PropTypes from 'prop-types';

function ViewPostModal({
  show, setShow, title, post,
}) {
  const handleClose = () => setShow(false);
  const { content, author, embeddedData } = post;

  const embeddedDataJson = JSON.stringify(embeddedData, null, 2);

  return (
    <Modal show={show} onHide={handleClose}>
      <Modal.Header closeButton>
        <Modal.Title>
          {title}
        </Modal.Title>
      </Modal.Header>
      <Modal.Body>
        <h6>
          Author:
          {' '}
          {author}
        </h6>
        <hr />
        <p className="post-content">
          {content}
        </p>
        {embeddedData && Object.entries(embeddedData).length && (
          <pre>
            {embeddedDataJson}
          </pre>
        )}
      </Modal.Body>
      <Modal.Footer>
        <Button variant="secondary" onClick={handleClose}>
          Close
        </Button>
      </Modal.Footer>
    </Modal>
  );
}

ViewPostModal.propTypes = {
  show: PropTypes.bool.isRequired,
  setShow: PropTypes.func.isRequired,
  title: PropTypes.string,
  post: PropTypes.object, // eslint-disable-line react/forbid-prop-types
};

ViewPostModal.defaultProps = {
  title: 'View Post',
  post: {},
};

export default ViewPostModal;
